@@ -7,6 +7,7 @@ import sys
 import os
 import signal
 import atexit
+import asyncio
 from datetime import datetime, timezone
 from typing import Optional, Dict, List, Any
 from rich.console import Console
@@ -38,7 +39,7 @@ class LiveMarketMonitor:
         self.config = config
         self.market_id = market_id
         self.category = category
-        self.console = Console()
+        self.console = Console(theme=None, force_terminal=True)
         
         # Process tracking for cleanup
         self._live_display = None
@@ -303,9 +304,10 @@ class LiveMarketMonitor:
         return table
     
     def run_live_monitor(self):
-        """Run the live monitoring loop with log-style output"""
+        """Run the live monitoring loop with real-time trade feeds"""
         self.console.print(Panel(
-            "[bold red]🔴 LIVE MARKET MONITOR STARTED[/bold red]\n"
+            "[bold red]🔴 LIVE TRADE MONITOR STARTED[/bold red]\n"
+            "[dim]Monitoring individual trades in real-time[/dim]\n"
             "[dim]Press Ctrl+C to stop monitoring[/dim]",
             style="red"
         ))
@@ -313,47 +315,32 @@ class LiveMarketMonitor:
         self._running = True
 
         try:
-            # Initial data fetch to test
-            initial_data = self.get_market_data()
-            if not initial_data:
-                self.console.print(f"[red]❌ No data found for category: {self.category}[/red]")
-                self.console.print("[yellow]This might be due to API issues or no active markets[/yellow]")
+            # Get markets to monitor
+            markets_data = self.get_market_data()
+            if not markets_data:
+                self.console.print(f"[red]❌ No markets found for category: {self.category}[/red]")
                 return
 
-            self.console.print(f"[green]✅ Found {len(initial_data)} markets to monitor[/green]")
-            self.console.print(f"[cyan]📊 Monitoring {len(initial_data)} markets in real-time...[/cyan]")
+            # Extract market slugs for RTDS WebSocket subscription
+            market_slugs = []
+            market_titles = {}
+            
+            for market in markets_data:
+                market_slug = market.get("slug")
+                market_id = market.get("id")
+                if market_slug:
+                    market_slugs.append(market_slug)
+                    market_titles[market_slug] = market.get("title", "Unknown")
+                    # Also store by ID for fallback
+                    if market_id:
+                        market_titles[market_id] = market.get("title", "Unknown")
+
+            self.console.print(f"[green]✅ Found {len(market_slugs)} markets to monitor[/green]")
+            self.console.print(f"[cyan]📊 Subscribing to RTDS live trade feeds...[/cyan]")
             self.console.print("=" * 80)
 
-            # Log-style live output
-            last_update = {}
-            while self._running:
-                try:
-                    markets = self.get_market_data()
-                    current_time = datetime.now(timezone.utc).strftime("%H:%M:%S")
-
-                    for market in markets:
-                        market_id = market.get("id")
-                        if market_id not in last_update:
-                            # First time seeing this market
-                            self._print_market_update(market, current_time, "NEW")
-                            last_update[market_id] = self._get_market_values(market)
-                        else:
-                            # Check for changes
-                            old_values = last_update[market_id]
-                            new_values = self._get_market_values(market)
-
-                            if new_values != old_values:
-                                # Market has changed
-                                direction = self._get_change_direction(old_values, new_values)
-                                self._print_market_update(market, current_time, direction)
-                                last_update[market_id] = new_values
-
-                    time.sleep(1)  # Update every second for log-style output
-
-                except Exception as e:
-                    if self._running:  # Only log errors if we're still supposed to be running
-                        self.console.print(f"[red]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | ERROR: {e}[/red]")
-                    time.sleep(2)  # Wait longer on errors
+            # Run async WebSocket monitoring with market slugs
+            asyncio.run(self._run_websocket_monitor(market_slugs, market_titles))
 
         except KeyboardInterrupt:
             self.console.print(f"\n[yellow]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | 🔴 Live monitoring stopped by user[/yellow]")
@@ -362,6 +349,116 @@ class LiveMarketMonitor:
         finally:
             self._running = False
             self.cleanup()
+
+    async def _run_websocket_monitor(self, market_slugs: List[str], market_titles: Dict[str, str]):
+        """Run WebSocket monitoring for live trades"""
+        try:
+            # Connect to WebSocket
+            await self.clob_client.connect_websocket()
+            self.console.print("[green]✅ Connected to PolyMarket RTDS WebSocket[/green]")
+            
+            # Subscribe to trade feeds
+            await self.clob_client.subscribe_to_trades(market_slugs, lambda trade: self._handle_trade(trade, market_titles))
+            self.console.print(f"[green]✅ Subscribed to {len(market_slugs)} market feeds[/green]")
+            self.console.print()
+            self.console.print("[bold]🔴 LIVE TRADES (Real-time):[/bold]")
+            self.console.print("=" * 80)
+            
+            # Start listening for trades
+            await self.clob_client.listen_for_trades()
+            
+        except Exception as e:
+            self.console.print(f"[red]❌ WebSocket error: {e}[/red]")
+            # Fallback to polling mode
+            self.console.print("[yellow]⚠️ Falling back to polling mode...[/yellow]")
+            await self._run_polling_monitor(market_slugs, market_titles)
+        finally:
+            await self.clob_client.close_websocket()
+
+    async def _handle_trade(self, trade_data: Dict[str, Any], market_titles: Dict[str, str]):
+        """Handle incoming trade data from RTDS"""
+        try:
+            timestamp = datetime.now(timezone.utc).strftime("%H:%M:%S")
+            
+            # Extract trade details from RTDS format (based on official client docs)
+            market_id = trade_data.get("market", trade_data.get("market_slug", "unknown"))
+            market_title = market_titles.get(market_id, "Unknown Market")
+            
+            # Extract trade details - official RTDS format
+            size = float(trade_data.get("size", 0))
+            price = float(trade_data.get("price", 0))
+            side = trade_data.get("side", "unknown")  # BUY or SELL
+            maker_address = trade_data.get("maker_address", "unknown")
+            asset_id = trade_data.get("asset_id", "unknown")
+            
+            # Calculate notional value
+            notional = size * price
+            
+            # Format trade display based on official RTDS format
+            side_symbol = "🟢 BUY" if side.upper() == "BUY" else "🔴 SELL"
+            side_color = "green" if side.upper() == "BUY" else "red"
+            
+            # Format size and price
+            size_str = f"{size:.0f}" if size >= 1 else f"{size:.2f}"
+            price_str = f"${price:.4f}" if price < 1 else f"${price:.2f}"
+            notional_str = f"${notional:.0f}" if notional >= 1000 else f"${notional:.2f}"
+            
+            # Truncate market title and maker address
+            title_short = market_title[:25] + "..." if len(market_title) > 25 else market_title
+            maker_short = maker_address[:8] + "..." if len(maker_address) > 8 else maker_address
+            
+            # Print detailed trade information
+            self.console.print(
+                f"[{side_color}]{timestamp} | {title_short:<28} | {side_symbol} | "
+                f"{size_str:>8} @ {price_str:>8} | {notional_str:>8} | {maker_short}[/{side_color}]"
+            )
+            
+        except Exception as e:
+            self.console.print(f"[red]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | ERROR processing trade: {e}[/red]")
+            # Debug: print the raw trade data
+            self.console.print(f"[dim]Raw trade data: {trade_data}[/dim]")
+
+    async def _run_polling_monitor(self, market_slugs: List[str], market_titles: Dict[str, str]):
+        """Fallback polling mode when WebSocket fails"""
+        self.console.print("[yellow]📊 Polling mode - checking for changes every 2 seconds...[/yellow]")
+        
+        last_prices = {}
+        
+        while self._running:
+            try:
+                markets = self.get_market_data()
+                current_time = datetime.now(timezone.utc).strftime("%H:%M:%S")
+                
+                for market in markets:
+                    market_id = market.get("id")
+                    if not market_id:
+                        continue
+                    
+                    # Get current price
+                    current_price = self._get_market_values(market)['price']
+                    previous_price = last_prices.get(market_id)
+                    
+                    if previous_price is not None and current_price != previous_price:
+                        # Price changed - simulate a trade
+                        direction = "🟢 BUY" if current_price > previous_price else "🔴 SELL"
+                        color = "green" if current_price > previous_price else "red"
+                        
+                        market_title = market_titles.get(market_id, "Unknown")
+                        title_short = market_title[:30] + "..." if len(market_title) > 30 else market_title
+                        
+                        self.console.print(
+                            f"[{color}]{current_time} | {title_short:<33} | {direction} | "
+                            f"PRICE CHANGE | ${previous_price:.4f} → ${current_price:.4f}[/{color}]"
+                        )
+                    
+                    last_prices[market_id] = current_price
+                
+                await asyncio.sleep(2)  # Poll every 2 seconds
+                
+            except Exception as e:
+                if self._running:
+                    self.console.print(f"[red]{datetime.now(timezone.utc).strftime('%H:%M:%S')} | ERROR: {e}[/red]")
+                await asyncio.sleep(5)
     
     def cleanup(self):
         """Clean up resources and ensure complete termination"""
@@ -480,12 +577,14 @@ class LiveMarketMonitor:
                 values['volume'] /= 1000000
                 volume_display += "M"
 
-            if volume_display.endswith("K"):
-                volume_str = f"${values['volume']:{volume_display}}K"
-            elif volume_display.endswith("M"):
-                volume_str = f"${values['volume']:{volume_display}}M"
+            # Format volume properly
+            volume_value = values['volume']
+            if volume_value < 1000:
+                volume_str = f"${volume_value:.0f}"
+            elif volume_value < 1000000:
+                volume_str = f"${volume_value/1000:.0f}K"
             else:
-                volume_str = f"${values['volume']:{volume_display}}"
+                volume_str = f"${volume_value/1000000:.1f}M"
 
             # Color code based on direction
             if "UP" in direction:
